```python tags=["initialize"]
 
from matplotlib import pyplot

import numpy as np
from scipy.optimize import curve_fit
from scipy.integrate import quad

from common import draw_classic_axes, configure_plotting

configure_plotting()

def sqrt_plus(x):
    return np.sqrt(x * (x >= 0))

# Band structure parameters.
E_V, E_C, E_F = -1.2, 1.8, .4
E_D, E_A = E_C - .7, E_V + .5
m_h, m_e = 1, .5
```

# Semiconductor physics
_(based on chapters 17–18 of the book)_  


!!! success "Expected prior knowledge"

    Before the start of this lecture, you should be able to:

    - Simplify integral expressions by Taylor expansion
    - Compute the density of states of the free electron model
    - Apply the concepts of group velocity and effective mass to solve problems

!!! summary "Learning goals"

    After this lecture you will be able to:

    - Describe the concept of holes, and apply this concept to describe the properties of semiconductors
    - Compute the density of states of electrons in semiconductors
    - Compute the density of charge carriers and chemical potential as a function of temperature

??? info "Lecture video"

    <iframe width="100%" height="315" src="https://www.youtube-nocookie.com/embed/IxDp_JAtBQs" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>


Up until this point, we focused on calculating and understanding the band structures.
However, the dispersion of a band is only part of the story.
An empty band is not gonna lead to any interesting physical properties no matter how sophisticated it is.
Therefore, it is also important *how* bands are filled by the particles.
By carefully controlling the distribution of particles in the bands, we are able to engineer material properties that we require.
Without a doubt, the greatest example is *semiconductors* - the bedrock of all electronics. 
In this lecture, we shall grasp the basics of semiconductors by learning how to treat bands at different levels of filling.

## Review of band structure properties

Before proceeding further, it is vital to remind ourselves some of the concepts in band structures. 

* Group velocity $v=\hbar^{-1}\partial E(k)/\partial k$. 
Descibes how quickly electrons move within the lattice. 
* Effective mass $m_{eff} = \hbar^2\left(d^2 E(k)/dk^2\right)^{-1}$. 
Tells us how hard it is to *accelerate* the particles and is related to the curvature of the band.
* Density of states $g(E) = \sum_{\textrm{FS}} (dn/dk) \times (dk/dE)$. 
The amount of states per infinitesimal interval of energy at given energy. 
The quantity is vital in order to calculate any bulk property of the material such as conductivity, heat capacity, etc.

In order to check that everything makes sense, we apply the concepts to the free electron model:

$$H = \hbar^2 k^2/2m$$

The velocity is $\hbar^{-1}\partial E(k)/\partial k = \hbar k / m \equiv p/m$.  
The effective mass is $m_{eff} = \hbar^2\left(d^2 E(k)/dk^2\right)^{-1} = m$.

So in the simplest case the definitions match the usual expressions.

## Filled vs empty bands

We distinguish three different band filling types: filled, empty and partially filled. 
Let us start with the most extreme cases - filled and empty bands.
We treat these two cases together, because a completely filled band is very similar to a completely empty band.
For example, both filled and empty bands lead to zero current:
$$
\begin{align}
j = 2e \frac{1}{2\pi} \int_{-\pi/a}^{\pi/a} v(k) dk = 2e \frac{1}{2\pi \hbar} \int_{-\pi/a}^{\pi/a} \frac{dE}{dk} \times dk = \\
2e \frac{1}{2\pi \hbar} [E(-\pi/a) - E(\pi/a)] = 0.
\end{align}
$$
An empty band has no electrons and thus no current.
On the other hand, a filled band has an equal number of electrons going forwards and backwards which thus cancel and lead to zero current. 
Similar results apply to many other physical quantities such as heat capacity and magnetisation. 
Therefore, filled and empty bands do not affect most physical properties and can be disregarded.
As a result, rather than to consider thousands of bands that a material contains, we neglect most of them and just focus on partially filled bands around Fermi level.

## From electrons to holes

In order to understand partial filling, we begin with a simple analogy.
Let's say we have 100 chairs: 99 are occupied and 1 is empty.
To keep track which chair is occupied/empty, we could write down the occupation of each and every chair.
However, that would require a lot of unnecessary writing!
Instead, we only need to write down which chair is empty, because we know the rest wil be occupied. 
The same philosophy is applied to band filling. 
Instead of describing a lot of electrons that are present in an almost filled band, we focus on those that are absent.
The absence of an electron is called a **hole**: a state of a completely filled band with one particle missing.

![](figures/holes.svg)

In this schematic we can either say that 8×2 electron states are occupied (the system has 8×2 electrons counting spin), or 10×2 hole states are occupied.
A useful analogy to remember: glass half-full or glass half-empty.
Electron and hole pictures correspond to two different, but equivalent ways of describing the occupation of a band.
In practice, we choose to deal with electrons whenever a band is almost empty and holes when a band is almost full.

## Properties of holes

Let us compare the properties of electrons and holes.
The probability for an electron state to be occupied in equilibrium is given by $f(E)$:

$$f(E) = \frac{1}{e^{(E-E_F)/kT} + 1}.$$

On the other hand, since a hole is a missing electron, the probability for a hole state to be occupied is

$$f_h(E) = 1 - f(E) = 1 - \frac{1}{e^{(E-E_F)/kT} + 1} = \frac{1}{e^{(-E+E_F)/kT} + 1},$$

therefore for holes both energy $E_h= -E$ and $E_{F,h} = -E_F$.

The **momentum** $p_h$ of a hole should give the correct total momentum of a partially filled band if one sums momenta of all holes.
Therefore $p_h = -\hbar k$, where $k$ is the wave vector of the electron.

Similarly, the total **charge** should be the same regardless of whether we count electrons or holes, so holes have a positive charge $+e$ (electrons have $-e$).

On the other hand, the velocity of a hole is **the same**:
$$\frac{dE_h}{dp_h} = \frac{-dE}{-d\hbar k} = \frac{dE}{dp}.$$

Finally, we derive the hole effective mass from the equations of motion:

$$m_{h,i} \frac{d v}{d t} = +e (E + v\times B).$$

Comparing with

$$m_{e,i} \frac{d v}{d t} = -e (E + v\times B),$$

we get $m_{h,i} = -m_{e,i}$.
An additional band index $i$ was introduced to clarify that the electron/hole mass relation only applies to particles **within the same band**.

## Semiconductors: materials with two bands.

In semiconductors the Fermi level is between two bands.
The unoccupied band is the **conduction band**, the occupied one is the **valence band**. 
In the conduction band the **charge carriers** (particles carrying electric current) are electrons, in the valence band they are holes.

The occupation of the bands is dictated by the Fermi level. 
We can control the position of the Fermi level (or create additional excitations) making semiconductors conduct when needed.
The easiest way to control the Fermi level is through temperature by inducing thermal excitations. 
In most semiconductors, the temperature is always smaller than the size of the band gap $k_b T \ll E_G$.
As a result, only the bottom of the conduction band has electrons and the top of the valence band has holes.
Therefore we can approximate the dispersion relation of both bands as parabolic.

![](figures/semiconductor.svg)

Or in other words

$$E_e = E_c + \frac{\hbar^2k^2}{2m_e}$$
$$E_h = E_{v,h} + \frac{\hbar^2k^2}{2m_h} = -E_{v} + \frac{\hbar^2k^2}{2m_h},$$

with the corresponding density of states

$$ g(E) = (2m_e)^{3/2}\sqrt{E-E_c}/2\pi^2\hbar^3$$
$$ g_h(E_h) = (2m_h)^{3/2}\sqrt{E_h+E_v}/2\pi^2\hbar^3.$$

Here $E_c$ is the energy of an electron at the bottom of the conduction band and $E_v$ is the energy of an electron at the top of the valence band.
Observe that because we are describing particles in the valence band as holes, $m_h > 0$ and $E_h > -E_v$.
Lastly, it is important to point out the notation that we adopt here. 
In the above plot, $m_h \neq -m_e$ because it refers to two **different** bands: valance band for holes and conduction band for electrons. 
In most literature, the band indices are neglected such that $m_{h,v} \to $m_{h}$ and $m_{e,c} \to m_e$. 


??? question "a photon gives a single electron enough energy to move from the valence band to the conduction band. How many particles does this process create?"
    Two: one electron and one hole.

## Semiconductor density of states and Fermi level

### Intrinsic semiconductor

```python
E = np.linspace(-3, 3, 1000)
fig, ax = pyplot.subplots()

n_F = 1/(np.exp(2*(E - E_F)) + 1)
g_e = m_e * sqrt_plus(E - E_C)
g_h = m_h * sqrt_plus(E_V - E)
ax.plot(E, g_e, label="$g_e$")
ax.plot(E, g_h, label="$g_h$")
ax.plot(E, 10 * g_h * (1-n_F), label="$n_h$")
ax.plot(E, 10 * g_e * n_F, label="$n_e$")
ax.plot(E, n_F, label="$n_F$", linestyle='dashed')
ax.set_ylim(top=1.5)

ax.set_xlabel('$E$')
ax.set_ylabel('$g$')
ax.set_xticks([E_V, E_C, E_F])
ax.set_xticklabels(['$E_V$', '$E_C$', '$E_F$'])
ax.legend()
draw_classic_axes(ax, xlabeloffset=.2)
```

**The key algorithm of describing the state of a semiconductor:**

1. Compute the density of states of all types of particles.
2. Calculate the number of electrons in the conduction band and holes in the valence band, assuming a certain value of $E_F$
3. Write down the charge balance condition: the difference between electrons and holes should equal the total charge of the semiconductor.
4. Apply approximations to simplify the equations (this is important!).
5. Find $E_F$ and concentrations of electrons and holes

Applying the first two steps of the algorithm:

$$n_h = \int_{-E_v}^\infty f_h(E_h) g_h(E_h) dE_h = \int_{-E_v}^\infty\frac{(2m_h)^{3/2}}{2\pi^2\hbar^3}\sqrt{E_h+E_v}\frac{1}{e^{(E_h+E_F)/kT}+1}dE_h$$

$$n_e = \int_{E_c}^\infty f(E)g_e(E)dE = \int_{E_c}^\infty\frac{(2m_e)^{3/2}}{2\pi^2\hbar^3} \sqrt{E-E_c}\frac{1}{e^{(E-E_F)/kT}+1}dE.$$

Note that whenever calculating the hole dependent quantities, we replace all the relevant physical quantities with their hole equivalents.
Since the hole energy is opposite $E_h = -E$, we replace the Fermi energy $E_F \to -E_F$ and the bottom of the valance band by $E_v \to -E_v$ in the integration limits.

In the third step, we need to solve the equation under charge balance $n_e = n_h$.
The equation is not a pleasant one and cannot be solved analytically unless an approximation is made.
Therfore, the fourth step assumes that the Fermi level is far from both bands $E_F-E_v \gg kT$ and $E_c - E_F \gg kT$.
As a result, the Fermi-Dirac distribution is approximately similar to Boltzmann distribution:

$$
f(E)_{e/h} \approx e^{-(E_{e/h}\pm E_F)/kT}.
$$

Now we can move to the last step and calculate $n_e$ and $n_h$:

$$
n_h \approx \frac{(2m_h)^{3/2}}{2\pi^2\hbar^3}e^{-E_F/kT} \int_{-E_v}^\infty\sqrt{E_h+E_v}e^{-E_h/kT}dE_h =
N_V e^{E_v-E_F/kT},
$$

where we used $\int_0^\infty \sqrt{x}e^{-x}dx=\sqrt{\pi}/2$ and we defined 

$$
N_V = 2\left(\frac{2\pi m_h kT}{h^2}\right)^{3/2}.
$$

We see that holes are exponentially activated into the valence band. 

??? question "how large is $N_V$ at room temperature? (hard question)"
    If $kT \sim 1\textrm{eV}$ (the typical energy size of a band), then electrons in the whole band may be excited and $N_V \sim 1$ per unit cell. On the other hand, $N_V \sim T^{3/2}$ Therefore $N_V \sim (kT/1 \textrm{eV})^{3/2}\sim 1\%$.

Similarly for electrons:

$$
n_e = N_C e^{-(E_c - E_F)/kT},\quad N_C = 2\left(\frac{2\pi m_e kT}{h^2}\right)^{3/2}.
$$


Combining everything together:

$$
n_h \approx N_V e^{E_v-E_F/kT} = N_C e^{-(E_c-E_F)/kT} \approx n_e.
$$

Solving for $E_F$:

$$
E_F = \frac{E_c + E_v}{2} - \frac{3}{4}kT\ln(m_e/m_h).
$$

An extra observation: regardless of where $E_F$ is located, $n_e n_h = N_C N_V e^{-E_g/kT} \equiv n_i^2$, where $E_g=E_c-E_v$ is the band gap of the semiconductor.

$n_i$ is the **intrinsic carrier concentration**, and for a pristine semiconductor $n_e = n_h = n_i$.

> The equation
> $$n_e n_h = n_i^2$$
> is the **law of mass action**. The name is borrowed from chemistry, and describes the equilibrium concentration of two reagents in a reaction $A+B \leftrightarrow AB$. Here electrons and hole constantly split and recombine.

### Conduction

Earlier, we deduced that empty and filled bands provide no current. 
We finish the analysis by considering partially filled bands of an intrinsic (pristine) semiconductor.
To calculate the current, we utilize the Drude model and sum the electron and hole contributions:

$$j = -n_e e v_e + n_h e v_h $$

$$ -m_e v_e /\tau_e = -eE;\quad -m_h v_h /\tau_h = eE.$$

We see that despite opposite velocity signs for electrons and holes, they carry electric current in the same direction:

$$ \sigma \equiv \frac{j}{E} = \left(\frac{n_e e^2 \tau_e}{m_e}+\frac{n_h e^2 \tau_h}{m_h}\right) = n_e e \mu_e + n_h e \mu_h.$$

We know that for intrinsic semiconductors, the hole/electron densities are $n_e = n_h = n_i \propto e^{-E_G/kT}$.
Therefore, it is possible to measure the band gap of an intrinsic semiconductor by looking at the temperature dependant conductivity $E_G \approx d \ln \sigma / d [kT]^{-1}$.
Additional information can be obtained using Hall effect.
However Hall effect is much more complex in semiconductors since only the current in the direction perpendicular to the applied electric field must vanish.
This, however only means that the electron current is opposite of the hole current in that direction, not that the electrons and holes move parallel to the applied current.

## Exercises

#### Exercise 1: Energy, mass, velocity and cyclotron motion of electrons and holes

  1. Consider the top of the valence band of a semiconductor (see [above](#semiconductors-materials-with-two-bands)). Does an electron near the top of the valence band have a positive or a negative effective mass? Does the electron's energy increase or decrease as $k$ increases from 0? Does the electron have a positive or negative group velocity for $k>0$?
  2. Answer the same last 3 questions for a hole in the valence band.
  3. We now consider an electron in a 2D semiconductor near the bottom of the conduction band described by an energy dispersion $E=E_{G}+\frac{\hbar^2}{2m_{eff}}(k_x^2+k_y^2)$. The electron's velocity is given by $\mathbf{v}=\nabla_\mathbf{k} E/\hbar = \frac{1}{\hbar}(\frac{\partial E}{\partial k_x}\mathbf{\hat{x}} + \frac{\partial E}{\partial k_y}\mathbf{\hat{y}})$. Suppose we turn on a magnetic field $B$ in the $z$-direction. Write down the equation of motion for this electron (neglecting collisions). What is the shape of the motion of the electron? What is the characteristic 'cyclotron' frequency of this motion? What is the direction of the Lorentz force with respect to $\nabla_\mathbf{k} E$? 
  4. Suppose we now consider a hole near the bottom of the conduction band and turn on a magnetic field $B$ in the $z$-direction. Is the direction of the circular motion (i.e., the chirality) of the hole the same as that of the electron? Would the chirality change if we instead consider a hole (or electron) near the top of the valence band?

#### Exercise 2: holes in Drude and tight binding model

1. Recall from the [Drude model](/3_drude_model/) that electrons give rise to a negative Hall coefficient. Explain why the Hall coefficient is positive if holes are the charge carriers in a material.
2. What would be the Hall coefficient if both carriers with equal concentration are present? Assume that both electrons and holes can move freely and have the same scattering time.

    Recall that the dispersion relation of a [1D single orbital tight binding chain](/7_tight_binding/) is given by
    $$E(k)=\varepsilon + 2t \cos(ka),$$
    where $a$ is the lattice constant and $\varepsilon$ and $t$ are tight binding parameters.

3. What is the group velocity and effective mass of this band for holes compared to that of electrons?
4. Give an integral expression of the hole concentration in this band given the chemical potential $\mu$ and temperature $T$.
5. Show that the sum of the electron and hole concentration in this band is constant as a function of the temperature.

#### Exercise 3: a 1D semiconductor
Suppose we have a 1D semiconductor with a conduction band described by $$E_{cb} = E_G - 2 t_{cb} [\cos(ka)-1],$$ and a valence band described by $$E_{vb} = 2 t_{vb} [\cos(ka)-1].$$ Furthermore, the chemical potential is set at $0 < \mu < E_G$.

1. Derive an expression for the group velocity and effective mass for electrons in the conduction bands and holes in the valence band.

    Assume that the Fermi level is far away from both bands. That is, $|E - \mu| \gg k_B T$. In that case, it is acceptable to approximate the bands for low $k$.

2. Why is it acceptable? Write down an approximate expression of these bands.
3. Write down an expression for the density of states _per unit length_ for both bands using the approximated expressions. Compare with the actual density of states per unit length. 
4. Calculate the electron density in the conduction band and the hole density in the valence band.
5. What would the chemical potential $\mu$ be in case of an intrinsic semiconductor?
